module Main exposing (main)

import Color exposing (Color)
import Html exposing (Html)
import Html.Attributes as A
import Ionicon
import Ionicon.Android as Android
import Ionicon.Ios as Ios
import Ionicon.Social as Social


main : Html msg
main =
    Html.div [ A.style [ ( "margin", "0" ), ( "padding", "10px 20px" ), ( "min-height", "100vh" ), ( "font-family", "sans-serif" ), ( "background", "rgb(34,34,34)" ), ( "color", "rgb(230,230,230)" ) ] ]
        [ Html.h1 [ A.style [ ( "margin", "10px 0" ), ( "border-bottom", "1px solid rgba(230,230,230,.5)" ) ] ] [ Html.text "Ionicons!" ]
        , Html.div [ A.style [ ( "padding", "10px 0" ) ] ] (List.map viewIcon ionicons)
        , Html.div [ A.style [ ( "padding", "10px 0" ) ] ] (List.map viewAndroidIcon androidIcons)
        , Html.div [ A.style [ ( "padding", "10px 0" ) ] ] (List.map viewIOSIcon iosIcons)
        , Html.div [ A.style [ ( "padding", "10px 0" ) ] ] (List.map viewSocialIcon socialIcons)
        ]


viewIcon : (Int -> Color -> Html msg) -> Html msg
viewIcon icon =
    icon 48 (Color.hsla 1 1 1 0.8)


viewAndroidIcon : (Int -> Color -> Html msg) -> Html msg
viewAndroidIcon icon =
    icon 48 (Color.hsl 33.3 0.7 0.8)


viewIOSIcon : (Int -> Color -> Html msg) -> Html msg
viewIOSIcon icon =
    icon 48 (Color.hsl 66.7 0.7 0.8)


viewSocialIcon : (Int -> Color -> Html msg) -> Html msg
viewSocialIcon icon =
    icon 48 (Color.hsl 0 0.7 0.8)


ionicons : List (Int -> Color -> Html msg)
ionicons =
    [ Ionicon.alertCircled
    , Ionicon.alert
    , Ionicon.aperture
    , Ionicon.archive
    , Ionicon.arrowDownA
    , Ionicon.arrowDownB
    , Ionicon.arrowDownC
    , Ionicon.arrowExpand
    , Ionicon.arrowGraphDownLeft
    , Ionicon.arrowGraphDownRight
    , Ionicon.arrowGraphUpLeft
    , Ionicon.arrowGraphUpRight
    , Ionicon.arrowLeftA
    , Ionicon.arrowLeftB
    , Ionicon.arrowLeftC
    , Ionicon.arrowMove
    , Ionicon.arrowResize
    , Ionicon.arrowReturnLeft
    , Ionicon.arrowReturnRight
    , Ionicon.arrowRightA
    , Ionicon.arrowRightB
    , Ionicon.arrowRightC
    , Ionicon.arrowShrink
    , Ionicon.arrowSwap
    , Ionicon.arrowUpA
    , Ionicon.arrowUpB
    , Ionicon.arrowUpC
    , Ionicon.asterisk
    , Ionicon.at
    , Ionicon.backspaceOutline
    , Ionicon.backspace
    , Ionicon.bag
    , Ionicon.batteryCharging
    , Ionicon.batteryEmpty
    , Ionicon.batteryFull
    , Ionicon.batteryHalf
    , Ionicon.batteryLow
    , Ionicon.beaker
    , Ionicon.beer
    , Ionicon.bluetooth
    , Ionicon.bonfire
    , Ionicon.bookmark
    , Ionicon.bowtie
    , Ionicon.briefcase
    , Ionicon.bug
    , Ionicon.calculator
    , Ionicon.calendar
    , Ionicon.camera
    , Ionicon.card
    , Ionicon.cash
    , Ionicon.chatboxWorking
    , Ionicon.chatbox
    , Ionicon.chatboxes
    , Ionicon.chatbubbleWorking
    , Ionicon.chatbubble
    , Ionicon.chatbubbles
    , Ionicon.checkmarkCircled
    , Ionicon.checkmarkRound
    , Ionicon.checkmark
    , Ionicon.chevronDown
    , Ionicon.chevronLeft
    , Ionicon.chevronRight
    , Ionicon.chevronUp
    , Ionicon.clipboard
    , Ionicon.clock
    , Ionicon.closeCircled
    , Ionicon.closeRound
    , Ionicon.close
    , Ionicon.closedCaptioning
    , Ionicon.cloud
    , Ionicon.codeDownload
    , Ionicon.codeWorking
    , Ionicon.code
    , Ionicon.coffee
    , Ionicon.compass
    , Ionicon.compose
    , Ionicon.connectionBars
    , Ionicon.contrast
    , Ionicon.crop
    , Ionicon.cube
    , Ionicon.disc
    , Ionicon.documentText
    , Ionicon.document
    , Ionicon.drag
    , Ionicon.earth
    , Ionicon.easel
    , Ionicon.edit
    , Ionicon.egg
    , Ionicon.eject
    , Ionicon.emailUnread
    , Ionicon.email
    , Ionicon.erlenmeyerFlaskBubbles
    , Ionicon.erlenmeyerFlask
    , Ionicon.eyeDisabled
    , Ionicon.eye
    , Ionicon.female
    , Ionicon.filing
    , Ionicon.filmMarker
    , Ionicon.fireball
    , Ionicon.flag
    , Ionicon.flame
    , Ionicon.flashOff
    , Ionicon.flash
    , Ionicon.folder
    , Ionicon.forkRepo
    , Ionicon.fork
    , Ionicon.forward
    , Ionicon.funnel
    , Ionicon.gearA
    , Ionicon.gearB
    , Ionicon.grid
    , Ionicon.hammer
    , Ionicon.happyOutline
    , Ionicon.happy
    , Ionicon.headphone
    , Ionicon.heartBroken
    , Ionicon.heart
    , Ionicon.helpBuoy
    , Ionicon.helpCircled
    , Ionicon.help
    , Ionicon.home
    , Ionicon.icecream
    , Ionicon.image
    , Ionicon.images
    , Ionicon.informationCircled
    , Ionicon.information
    , Ionicon.ionic
    , Ionicon.ipad
    , Ionicon.iphone
    , Ionicon.ipod
    , Ionicon.jet
    , Ionicon.key
    , Ionicon.knife
    , Ionicon.laptop
    , Ionicon.leaf
    , Ionicon.levels
    , Ionicon.lightbulb
    , Ionicon.link
    , Ionicon.loadA
    , Ionicon.loadB
    , Ionicon.loadC
    , Ionicon.loadD
    , Ionicon.location
    , Ionicon.lockCombination
    , Ionicon.locked
    , Ionicon.logIn
    , Ionicon.logOut
    , Ionicon.loop
    , Ionicon.magnet
    , Ionicon.male
    , Ionicon.man
    , Ionicon.map
    , Ionicon.medkit
    , Ionicon.merge
    , Ionicon.micA
    , Ionicon.micB
    , Ionicon.micC
    , Ionicon.minusCircled
    , Ionicon.minusRound
    , Ionicon.minus
    , Ionicon.modelS
    , Ionicon.monitor
    , Ionicon.more
    , Ionicon.mouse
    , Ionicon.musicNote
    , Ionicon.naviconRound
    , Ionicon.navicon
    , Ionicon.navigate
    , Ionicon.network
    , Ionicon.noSmoking
    , Ionicon.nuclear
    , Ionicon.outlet
    , Ionicon.paintbrush
    , Ionicon.paintbucket
    , Ionicon.paperclip
    , Ionicon.pause
    , Ionicon.personAdd
    , Ionicon.personStalker
    , Ionicon.person
    , Ionicon.pieGraph
    , Ionicon.pin
    , Ionicon.pinpoint
    , Ionicon.pizza
    , Ionicon.plane
    , Ionicon.planet
    , Ionicon.play
    , Ionicon.playstation
    , Ionicon.plusCircled
    , Ionicon.plusRound
    , Ionicon.plus
    , Ionicon.podium
    , Ionicon.pound
    , Ionicon.power
    , Ionicon.pricetag
    , Ionicon.pricetags
    , Ionicon.printer
    , Ionicon.pullRequest
    , Ionicon.qrScanner
    , Ionicon.quote
    , Ionicon.radioWaves
    , Ionicon.record
    , Ionicon.refresh
    , Ionicon.replyAll
    , Ionicon.reply
    , Ionicon.ribbonA
    , Ionicon.ribbonB
    , Ionicon.sadOutline
    , Ionicon.sad
    , Ionicon.scissors
    , Ionicon.search
    , Ionicon.settings
    , Ionicon.share
    , Ionicon.shuffle
    , Ionicon.skipBackward
    , Ionicon.skipForward
    , Ionicon.soupCanOutline
    , Ionicon.soupCan
    , Ionicon.speakerphone
    , Ionicon.speedometer
    , Ionicon.spoon
    , Ionicon.star
    , Ionicon.starBars
    , Ionicon.steam
    , Ionicon.stop
    , Ionicon.thermometer
    , Ionicon.thumbsdown
    , Ionicon.thumbsup
    , Ionicon.toggleFilled
    , Ionicon.toggle
    , Ionicon.transgender
    , Ionicon.trashA
    , Ionicon.trashB
    , Ionicon.trophy
    , Ionicon.tshirtOutline
    , Ionicon.tshirt
    , Ionicon.umbrella
    , Ionicon.university
    , Ionicon.unlocked
    , Ionicon.upload
    , Ionicon.usb
    , Ionicon.videocamera
    , Ionicon.volumeHigh
    , Ionicon.volumeLow
    , Ionicon.volumeMedium
    , Ionicon.volumeMute
    , Ionicon.wand
    , Ionicon.waterdrop
    , Ionicon.wifi
    , Ionicon.wineglass
    , Ionicon.woman
    , Ionicon.wrench
    , Ionicon.xbox
    ]


androidIcons : List (Int -> Color -> Html msg)
androidIcons =
    [ Android.addCircle
    , Android.add
    , Android.alarmClock
    , Android.alert
    , Android.apps
    , Android.archive
    , Android.arrowBack
    , Android.arrowDown
    , Android.arrowDropdownCircle
    , Android.arrowDropdown
    , Android.arrowDropleftCircle
    , Android.arrowDropleft
    , Android.arrowDroprightCircle
    , Android.arrowDropright
    , Android.arrowDropupCircle
    , Android.arrowDropup
    , Android.arrowForward
    , Android.arrowUp
    , Android.attach
    , Android.bar
    , Android.bicycle
    , Android.boat
    , Android.bookmark
    , Android.bulb
    , Android.bus
    , Android.calendar
    , Android.call
    , Android.camera
    , Android.cancel
    , Android.car
    , Android.cart
    , Android.chat
    , Android.checkboxBlank
    , Android.checkboxOutlineBlank
    , Android.checkboxOutline
    , Android.checkbox
    , Android.checkmarkCircle
    , Android.clipboard
    , Android.close
    , Android.cloudCircle
    , Android.cloudDone
    , Android.cloudOutline
    , Android.cloud
    , Android.colorPalette
    , Android.compass
    , Android.contact
    , Android.contacts
    , Android.contract
    , Android.create
    , Android.delete
    , Android.desktop
    , Android.document
    , Android.doneAll
    , Android.done
    , Android.download
    , Android.drafts
    , Android.exit
    , Android.expand
    , Android.favoriteOutline
    , Android.favorite
    , Android.film
    , Android.folderOpen
    , Android.folder
    , Android.funnel
    , Android.globe
    , Android.hand
    , Android.hangout
    , Android.happy
    , Android.home
    , Android.image
    , Android.laptop
    , Android.list
    , Android.locate
    , Android.lock
    , Android.mail
    , Android.map
    , Android.menu
    , Android.microphoneOff
    , Android.microphone
    , Android.moreHorizontal
    , Android.moreVertical
    , Android.navigate
    , Android.notificationsNone
    , Android.notificationsOff
    , Android.notifications
    , Android.open
    , Android.options
    , Android.people
    , Android.personAdd
    , Android.person
    , Android.phoneLandscape
    , Android.phonePortrait
    , Android.pin
    , Android.plane
    , Android.playstore
    , Android.print
    , Android.radioButtonOff
    , Android.radioButtonOn
    , Android.refresh
    , Android.removeCircle
    , Android.remove
    , Android.restaurant
    , Android.sad
    , Android.search
    , Android.send
    , Android.settings
    , Android.shareAlt
    , Android.share
    , Android.starHalf
    , Android.starOutline
    , Android.star
    , Android.stopwatch
    , Android.subway
    , Android.sunny
    , Android.sync
    , Android.textsms
    , Android.time
    , Android.train
    , Android.unlock
    , Android.upload
    , Android.volumeDown
    , Android.volumeMute
    , Android.volumeOff
    , Android.volumeUp
    , Android.walk
    , Android.warning
    , Android.watch
    , Android.wifi
    ]


iosIcons : List (Int -> Color -> Html msg)
iosIcons =
    [ Ios.alarmOutline
    , Ios.alarm
    , Ios.albumsOutline
    , Ios.albums
    , Ios.americanfootballOutline
    , Ios.americanfootball
    , Ios.analyticsOutline
    , Ios.analytics
    , Ios.arrowBack
    , Ios.arrowDown
    , Ios.arrowForward
    , Ios.arrowLeft
    , Ios.arrowRight
    , Ios.arrowThinDown
    , Ios.arrowThinLeft
    , Ios.arrowThinRight
    , Ios.arrowThinUp
    , Ios.arrowUp
    , Ios.atOutline
    , Ios.at
    , Ios.barcodeOutline
    , Ios.barcode
    , Ios.baseballOutline
    , Ios.baseball
    , Ios.basketballOutline
    , Ios.basketball
    , Ios.bellOutline
    , Ios.bell
    , Ios.bodyOutline
    , Ios.body
    , Ios.boltOutline
    , Ios.bolt
    , Ios.bookOutline
    , Ios.book
    , Ios.bookmarksOutline
    , Ios.bookmarks
    , Ios.boxOutline
    , Ios.box
    , Ios.briefcaseOutline
    , Ios.briefcase
    , Ios.browsersOutline
    , Ios.browsers
    , Ios.calculatorOutline
    , Ios.calculator
    , Ios.calendarOutline
    , Ios.calendar
    , Ios.cameraOutline
    , Ios.camera
    , Ios.cartOutline
    , Ios.cart
    , Ios.chatboxesOutline
    , Ios.chatboxes
    , Ios.chatbubbleOutline
    , Ios.chatbubble
    , Ios.checkmarkEmpty
    , Ios.checkmarkOutline
    , Ios.checkmark
    , Ios.circleFilled
    , Ios.circleOutline
    , Ios.clockOutline
    , Ios.clock
    , Ios.closeEmpty
    , Ios.closeOutline
    , Ios.close
    , Ios.cloudDownloadOutline
    , Ios.cloudDownload
    , Ios.cloudOutline
    , Ios.cloudUploadOutline
    , Ios.cloudUpload
    , Ios.cloud
    , Ios.cloudyNightOutline
    , Ios.cloudyNight
    , Ios.cloudyOutline
    , Ios.cloudy
    , Ios.cogOutline
    , Ios.cog
    , Ios.colorFilterOutline
    , Ios.colorFilter
    , Ios.colorWandOutline
    , Ios.colorWand
    , Ios.composeOutline
    , Ios.compose
    , Ios.contactOutline
    , Ios.contact
    , Ios.copyOutline
    , Ios.copy
    , Ios.cropStrong
    , Ios.crop
    , Ios.downloadOutline
    , Ios.download
    , Ios.drag
    , Ios.emailOutline
    , Ios.email
    , Ios.eyeOutline
    , Ios.eye
    , Ios.fastforwardOutline
    , Ios.fastforward
    , Ios.filingOutline
    , Ios.filing
    , Ios.filmOutline
    , Ios.film
    , Ios.flagOutline
    , Ios.flag
    , Ios.flameOutline
    , Ios.flame
    , Ios.flaskOutline
    , Ios.flask
    , Ios.flowerOutline
    , Ios.flower
    , Ios.folderOutline
    , Ios.folder
    , Ios.footballOutline
    , Ios.football
    , Ios.gameControllerAOutline
    , Ios.gameControllerA
    , Ios.gameControllerBOutline
    , Ios.gameControllerB
    , Ios.gearOutline
    , Ios.gear
    , Ios.glassesOutline
    , Ios.glasses
    , Ios.gridViewOutline
    , Ios.gridView
    , Ios.heartOutline
    , Ios.heart
    , Ios.helpEmpty
    , Ios.helpOutline
    , Ios.help
    , Ios.homeOutline
    , Ios.home
    , Ios.infiniteOutline
    , Ios.infinite
    , Ios.informationEmpty
    , Ios.informationOutline
    , Ios.information
    , Ios.ionicOutline
    , Ios.keypadOutline
    , Ios.keypad
    , Ios.lightbulbOutline
    , Ios.lightbulb
    , Ios.listOutline
    , Ios.list
    , Ios.locationOutline
    , Ios.location
    , Ios.lockedOutline
    , Ios.locked
    , Ios.loopStrong
    , Ios.loop
    , Ios.medicalOutline
    , Ios.medical
    , Ios.medkitOutline
    , Ios.medkit
    , Ios.micOff
    , Ios.micOutline
    , Ios.mic
    , Ios.minusEmpty
    , Ios.minusOutline
    , Ios.minus
    , Ios.monitorOutline
    , Ios.monitor
    , Ios.moonOutline
    , Ios.moon
    , Ios.moreOutline
    , Ios.more
    , Ios.musicalNote
    , Ios.musicalNotes
    , Ios.navigateOutline
    , Ios.navigate
    , Ios.nutritionOutline
    , Ios.nutrition
    , Ios.paperOutline
    , Ios.paper
    , Ios.paperplaneOutline
    , Ios.paperplane
    , Ios.partlySunnyOutline
    , Ios.partlySunny
    , Ios.pauseOutline
    , Ios.pause
    , Ios.pawOutline
    , Ios.paw
    , Ios.peopleOutline
    , Ios.people
    , Ios.personOutline
    , Ios.person
    , Ios.personaddOutline
    , Ios.personadd
    , Ios.photosOutline
    , Ios.photos
    , Ios.pieOutline
    , Ios.pie
    , Ios.pintOutline
    , Ios.pint
    , Ios.playOutline
    , Ios.play
    , Ios.plusEmpty
    , Ios.plusOutline
    , Ios.plus
    , Ios.pricetagOutline
    , Ios.pricetag
    , Ios.pricetagsOutline
    , Ios.pricetags
    , Ios.printerOutline
    , Ios.printer
    , Ios.pulseStrong
    , Ios.pulse
    , Ios.rainyOutline
    , Ios.rainy
    , Ios.recordingOutline
    , Ios.recording
    , Ios.redoOutline
    , Ios.redo
    , Ios.refreshEmpty
    , Ios.refreshOutline
    , Ios.refresh
    , Ios.reload
    , Ios.reverseCameraOutline
    , Ios.reverseCamera
    , Ios.rewindOutline
    , Ios.rewind
    , Ios.roseOutline
    , Ios.rose
    , Ios.searchStrong
    , Ios.search
    , Ios.settingsStrong
    , Ios.settings
    , Ios.shuffleStrong
    , Ios.shuffle
    , Ios.skipbackwardOutline
    , Ios.skipbackward
    , Ios.skipforwardOutline
    , Ios.skipforward
    , Ios.snowy
    , Ios.speedometerOutline
    , Ios.speedometer
    , Ios.starHalf
    , Ios.starOutline
    , Ios.star
    , Ios.stopwatchOutline
    , Ios.stopwatch
    , Ios.sunnyOutline
    , Ios.sunny
    , Ios.telephoneOutline
    , Ios.telephone
    , Ios.tennisballOutline
    , Ios.tennisball
    , Ios.thunderstormOutline
    , Ios.thunderstorm
    , Ios.timeOutline
    , Ios.time
    , Ios.timerOutline
    , Ios.timer
    , Ios.toggleOutline
    , Ios.toggle
    , Ios.trashOutline
    , Ios.trash
    , Ios.undoOutline
    , Ios.undo
    , Ios.unlockedOutline
    , Ios.unlocked
    , Ios.uploadOutline
    , Ios.upload
    , Ios.videocamOutline
    , Ios.videocam
    , Ios.volumeHigh
    , Ios.volumeLow
    , Ios.wineglassOutline
    , Ios.wineglass
    , Ios.worldOutline
    , Ios.world
    ]


socialIcons : List (Int -> Color -> Html msg)
socialIcons =
    [ Social.androidOutline
    , Social.android
    , Social.angularOutline
    , Social.angular
    , Social.appleOutline
    , Social.apple
    , Social.bitcoinOutline
    , Social.bitcoin
    , Social.bufferOutline
    , Social.buffer
    , Social.chromeOutline
    , Social.chrome
    , Social.codepenOutline
    , Social.codepen
    , Social.css3Outline
    , Social.css3
    , Social.designernewsOutline
    , Social.designernews
    , Social.dribbbleOutline
    , Social.dribbble
    , Social.dropboxOutline
    , Social.dropbox
    , Social.euroOutline
    , Social.euro
    , Social.facebookOutline
    , Social.facebook
    , Social.foursquareOutline
    , Social.foursquare
    , Social.freebsdDevil
    , Social.githubOutline
    , Social.github
    , Social.googleOutline
    , Social.google
    , Social.googleplusOutline
    , Social.googleplus
    , Social.hackernewsOutline
    , Social.hackernews
    , Social.html5Outline
    , Social.html5
    , Social.instagram
    , Social.javascriptOutline
    , Social.javascript
    , Social.linkedinOutline
    , Social.linkedin
    , Social.markdown
    , Social.nodejs
    , Social.octocat
    , Social.pinterestOutline
    , Social.pinterest
    , Social.python
    , Social.redditOutline
    , Social.reddit
    , Social.rssOutline
    , Social.rss
    , Social.sass
    , Social.skypeOutline
    , Social.skype
    , Social.snapchatOutline
    , Social.snapchat
    , Social.tumblrOutline
    , Social.tumblr
    , Social.tux
    , Social.twitchOutline
    , Social.twitch
    , Social.twitterOutline
    , Social.twitter
    , Social.usdOutline
    , Social.usd
    , Social.vimeoOutline
    , Social.vimeo
    , Social.whatsappOutline
    , Social.whatsapp
    , Social.windowsOutline
    , Social.windows
    , Social.wordpressOutline
    , Social.wordpress
    , Social.yahooOutline
    , Social.yahoo
    , Social.yenOutline
    , Social.yen
    , Social.youtubeOutline
    , Social.youtube
    ]
